clc
clear all
format long e


param.S_ref = 12.0687;      %reference area of capsule (m^2)
param.R = 6371e3;           %Earth's radius (m)
param.g_surf = 9.80665;     %gravity at surface of the Earth (m/s^2)
param.rho_surf = 2.7649e-4;	%density of Earth's atmosphere at the surface (kg/m^3)
param.m_vcl = 5500;         %mass of the capsule (kg)
param.alt_ref = 60e3;       %end of sensible atmosphere (m)
param.H = 7.00e3;           %scaled height (m)
param.dt = 0.1;             %time step

%%

%STATE VARIABLE
x.V = 7162.8;               %re-entry velocity
x.phi = 10.556;             %angular displacement (range)
x.theta = -2.0;             %flight path angle
x.alt = 80e3;               %re-entry altitude

alpha = 53;                 %angle of attack
t = 0;                      %initialize time
n = 1;

time(1,1) = t;
velocity(1,1) = x.V;
range(1,1) = x.phi;
flight_angle(1,1) = x.theta;
altitude(1,1) = x.alt;


    while x.V > 500
        %INTEGRATE EQUATIONS OF MOTION
        %INTPUTS:   system state x at time t
        %           alpha
        %           parameters
        %OUTPUTS:   updated system state

        t = t + param.dt;

        [x] = integrate_Motion_EQS(x, alpha, param);

        time(end+1,1) = t;                  %store time values for plotting
        velocity(end+1,1) = x.V;
        range(end+1,1) = x.phi;
        flight_angle(end+1,1) = x.theta;
        altitude(end+1,1) = x.alt;

        n = n + 1;
    end

%% PLOTTING
figure(1)
plot(time,altitude/1000);
xlabel('Time (s)')
ylabel('Altitude (km)')

figure(2)
plot(time,range*pi/180);
xlabel('Time (s)')
ylabel('Range (rad)')

figure(3)
plot(time,velocity/1000);
xlabel('Time (s)')
ylabel('Velocity (km/s)')

figure(4)
plot(time,flight_angle*pi/180);
xlabel('Time (s)')
ylabel('Fligth-path angle (rad)')
